@@ -169,6 +169,7 @@ class Job(Serializable):
         # Save information about the Job environment in which it was created
         self.network_id = node.parent.long_id
         self.network_version = str(node.parent.network_version)
+        self.network_scope = node.parent.network_scope
         self.run_id = node.parent.id
         self.node = node
         self.node_id = node.id
@@ -259,6 +260,7 @@ class Job(Serializable):
             # IDs relate to the job
             'network_id': self.network_id,
             'network_version': self.network_version,
+            'network_scope': self.network_scope,
             'run_id': self.run_id,
             'node_id': self.node_id,
             'node_global_id': self.node_global_id,
@@ -299,6 +301,8 @@ class Job(Serializable):
         :param dict state:
         """
         # Rename argument for backwards compatibility
+        self.network_scope = None
+
         if 'tool_name' in state:
             state['tool_id'] = state.pop('tool_name')
 
@@ -1251,7 +1255,7 @@ class SinkJob(Job):
         :return: the payload
         :rtype: dict
         """
-        payload = super(SinkJob, self).create_payload()
+        payload = super().create_payload()
         log.info('Temp payload: {}'.format(payload))
         log.info('Input data: {}'.format(payload['inputs']['input']))
         log.info('Input arguments: {}'.format(self.input_arguments['input'].data))
@@ -1370,6 +1374,25 @@ class SourceJob(Job):
         """
         return '<SourceJob\n  id={job.id}\n  tmpdir={job.tmpurl}/>'.format(job=self)
 
+    def create_payload(self):
+        """
+        Create the payload for this object based on all the input/output
+        arguments
+
+        :return: the payload
+        :rtype: dict
+        """
+        payload = super().create_payload()
+
+        # Inject network scope
+        input_part = payload['inputs']
+        for key, value in input_part.items():
+            new_value = tuple(vfs.expand_network_scope(x, network_scope=self.network_scope) for x in value)
+            print(f'New value: {new_value}')
+            input_part[key] = new_value
+
+        return payload
+
     def validate_results(self, payload):
         """
         Validate the results of the Job
