@@ -88,6 +88,20 @@ class NetworkRun(Serializable):
         self.network_version = network.version
         self.network_namespace = network.namespace
         self.network_filename = network.filename
+
+        network_scope = network.filename
+
+        if network_scope is not None:
+            network_scope = os.path.dirname(network_scope)
+
+            try:
+                network_scope = vfs_plugin.path_to_url(network_scope)
+            except exceptions.FastrMountUnknownError:
+                log.warning('Network scope is not in any known mounts, cannot transfer scope to execution nodes!')
+                network_scope = None
+
+        log.info(f'Detected network scope: {network_scope}')
+        self.network_scope = network_scope
         self.description = network.description
 
         # Info about the execution run
@@ -483,17 +497,21 @@ class NetworkRun(Serializable):
             if self.parent is not None:
                 executionlist = [x for x in executionlist if not isinstance(x, SinkNodeRun)]
 
+            # log.warning(f"===> {executionlist=}")
+            # test1 = [x.execute() for x in executionlist]
+            # log.warning(f"===> {test1=}")
+            # test2 = list(itertools.zip_longest(*test1))
+            # log.warning(f"===> {test2=}")
+
             for job_lists in itertools.zip_longest(*[x.execute() for x in executionlist]):
                 if not self.executing:
                     return
 
                 # Flatten the array of arrays while dropping the Nones (drained iterators)
-                job_list = [x for y in job_lists if y is not None for x in y]
+                job_list = (x for y in job_lists if y is not None for x in y)
 
                 # Only try to process chunks that actually have jobs...
-                if len(job_list) > 0:
-                    # First queue all jobs that need to run
-                    yield job_list
+                yield job_list
 
         log.debug('=== END GENERATE JOBS FOR {} ==='.format(self.id))
 
@@ -608,7 +626,7 @@ class NetworkRun(Serializable):
             self.set_data(sourcedata, sinkdata)
 
             # Select desired server execution plugin and instantiate
-            log.debug('Selecting {} as executor plugin'.format(config.execution_plugin))
+            log.info('Selecting {} as executor plugin'.format(config.execution_plugin))
 
             # Checlk what execution plugin to use
             if execution_plugin is None:
@@ -633,6 +651,7 @@ class NetworkRun(Serializable):
                     for job in job_list:
                         if not self.executing:
                             return
+                        log.info(f"Queueing job {job.id}")
                         execution_interface.queue_job(job)
 
                     log.info('Waiting for execution to finish...')
