@@ -448,7 +448,7 @@ class NodeRun(BaseNodeRun):
     def tool(self):
         return self._tool
 
-    def execute(self):
+    def _execute(self):
         """
         Execute the node and create the jobs that need to run
 
@@ -470,35 +470,26 @@ class NodeRun(BaseNodeRun):
             ', '.join('[{}: {}]'.format(name, size) for name, size in zip(self.dimnames, self.outputsize))
         ))
 
-        # Iterate over all combinations of input_groups to create sets of data
-        job_list = []
-
-        log.debug('InputGroups: {}'.format(list(input_groups.values())))
-        log.debug('Inputs: {}'.format([x for ig in input_groups.values() for x in ig.values()]))
-        log.debug('Sources: {}'.format([x.source for ig in input_groups.values() for x in ig.values()]))
-
         for sample_index, sample_id, job_data, job_depends, failed_annotations, status in self.input_group_combiner:
-            log.debug('----- START -----')
-            log.debug('INDEX: {}'.format(sample_index))
-            log.debug('SAMPLE_ID: {} {}'.format(repr(sample_id), sample_id))
-            log.debug('JOBDATA: {}'.format(job_data))
-            log.debug('JOBDEPS: {}'.format(job_depends))
-            log.debug('FAILS: {}'.format(failed_annotations))
-            log.debug('STATUS: {}'.format(status))
-            log.debug('------ END ------')
-
             job = self.create_job(sample_id, sample_index, job_data, job_depends, status)
 
             if status == SampleState.MISSING:
                 job.status = JobState.execution_skipped
                 job.write()
 
-            job_list.append(job)
+            yield job
 
-        log.debug('joblist: {}'.format(job_list))
         log.debug('===== END execute_node =====')
         self.drained = True
-        yield job_list
+
+    def execute(self):
+        """
+        Execute the node and create the jobs that need to run
+
+        :return: list of jobs to run
+        :rtype: list of :py:class:`Jobs <fastr.execution.job.Job>`
+        """
+        yield self._execute()
 
     def set_result(self, job, failed_annotation):
         """
