@@ -220,7 +220,7 @@ class SourceNodeRun(FlowNodeRun):
 
         self.outputsize = len(self._input_data),
 
-    def execute(self):
+    def _execute(self):
         """
         Execute the source node and create the jobs that need to run
 
@@ -234,8 +234,6 @@ class SourceNodeRun(FlowNodeRun):
             log.error(msg)
             raise exceptions.FastrValueError(msg)
 
-        joblist = []
-
         for index, (sample_id, value) in enumerate(self._input_data.items()):
             sample_index = SampleIndex(index)
 
@@ -283,10 +281,9 @@ class SourceNodeRun(FlowNodeRun):
             else:
                 # We found an URL, should be
                 log.debug('Spawning job for sample {} at {}'.format(sample_id, self.fullid))
-                joblist.append(self.create_job(sample_id, sample_index, {'input': value}, [], SampleState.VALID))
+                yield self.create_job(sample_id, sample_index, {'input': value}, [], SampleState.VALID)
 
         self.drained = True
-        yield joblist
 
     def create_job(self, sample_id, sample_index, job_data, job_dependencies, status, **kwargs):
         job = super(SourceNodeRun, self).create_job(sample_id, sample_index,
@@ -458,7 +455,7 @@ class ConstantNodeRun(SourceNodeRun):
         """
         return self._data
 
-    def execute(self):
+    def _execute(self):
         """
         Execute the constant node and create the jobs that need to run
 
@@ -469,5 +466,5 @@ class ConstantNodeRun(SourceNodeRun):
         self.set_data()
 
         # Run as a normal SourceNode
-        for joblist in super(ConstantNodeRun, self).execute():
-            yield joblist
+        for job in super(ConstantNodeRun, self)._execute():
+            yield job
