@@ -20,6 +20,7 @@ Fastr. The config object is stored directly in the fastr top-level module.
 
 import builtins
 import collections
+import collections.abc
 import importlib
 import inspect
 import json
@@ -57,9 +58,9 @@ class EmptyDefault(object):
         self._list_data = [NotImplemented]
         self._dict_data = collections.defaultdict(EmptyDefault)
 
-        if isinstance(data, collections.Mapping):
+        if isinstance(data, collections.abc.Mapping):
             self._dict_data.update(data)
-        elif isinstance(data, collections.Sequence):
+        elif isinstance(data, collections.abc.Sequence):
             self._list_data = list(data)
 
     # Any object be added in place (just replaces current value)
@@ -234,19 +235,25 @@ class Config(object):
         ),
         "types_path": (
             list,
-            [x for x in [os.path.join(USER_DIR, 'datatypes'), os.path.join(RESOURCE_DIR, 'datatypes')] if os.path.exists(x)],
+            [x for x in [os.path.join(USER_DIR, 'datatypes'),
+                         os.path.join(USER_DIR, 'fastrpi', 'datatypes'),
+                         os.path.join(RESOURCE_DIR, 'datatypes')] if os.path.exists(x)],
             "Directories to scan for datatypes",
             ['$userdir/datatypes', '$resourcedir/datatypes']
         ),
         "tools_path": (
             list,
-            [x for x in [os.path.join(USER_DIR, 'tools'), os.path.join(RESOURCE_DIR, 'tools')] if os.path.exists(x)],
+            [x for x in [os.path.join(USER_DIR, 'tools'),
+                         os.path.join(USER_DIR, 'fastrpi', 'tools'),
+                         os.path.join(RESOURCE_DIR, 'tools')] if os.path.exists(x)],
             "Directories to scan for tools",
             ['$userdir/tools', '$resourcedir/tools']
         ),
         "networks_path": (
             list,
-            [x for x in [os.path.join(USER_DIR, 'networks'), os.path.join(RESOURCE_DIR, 'networks')] if os.path.exists(x)],
+            [x for x in [os.path.join(USER_DIR, 'networks'),
+                         os.path.join(USER_DIR, 'fastrpi', 'networks'),
+                         os.path.join(RESOURCE_DIR, 'networks')] if os.path.exists(x)],
             "Directories to scan for networks",
             ['$userdir/networks', '$resourcedir/networks']
         ),
@@ -260,14 +267,18 @@ class Config(object):
             dict,
             {
                 'tmp': tempfile.gettempdir(),
+                'examples': os.path.join(SYSTEM_DIR, 'examples'),
                 'example_data': os.path.join(SYSTEM_DIR, 'examples', 'data'),
                 'home': os.path.expanduser('~'),
+                'fastr_home': USER_DIR,
             },
             "A dictionary containing all mount points in the VFS system",
             {
                 'tmp': '$TMPDIR',
+                'examples': '$systemdir/examples',
                 'example_data': '$systemdir/examples/data',
-                'home': '~/'
+                'home': '~/',
+                'fastr_home': "$FASTRHOME or ~/.fastr",
             }
         ),
         "preferred_types": (
