@@ -103,10 +103,14 @@ class Network(Serializable):
         if filename is None:
             frame = inspect.currentframe().f_back
             filename = frame.f_globals.get('__file__', None)
+
+            # If called from fastr api/planning, need to go a frame further back
+            while filename and re.match(r'.*[/\\]fastr[/\\](api|planning)[/\\]__init__\.py', filename):
+                frame = frame.f_back
+                filename = frame.f_globals.get('__file__', None)
+
             if filename is not None:
                 filename = os.path.abspath(filename)
-            else:
-                filename = 'python-shell'
 
         self.filename = filename
 
