@@ -480,16 +480,18 @@ class ExecutionPlugin(Plugin):
                     # Job is already removed
                     pass
 
-                if len(self.source_job_queue) > 0:
-                    fastr.log.debug('Taking source job from the queue')
-                    new_source_job = self.source_job_queue.popleft()
-                    while not new_source_job.status.idle:
-                        fastr.log.warning('Discarding non-idle queued source/sink job {} ({})'.format(
-                            new_source_job,
-                            new_source_job.status)
-                        )
-                        new_source_job = self.source_job_queue.popleft()
+        with self.source_queue_lock:
+            if self.source_job_limit > 0 and len(self.queued_source_jobs) < self.source_job_limit and len(self.source_job_queue) > 0:
+                fastr.log.debug('Taking source job from the queue')
+                for new_source_job in self.source_job_queue:
+                    if new_source_job.status.idle:
+                        self.source_job_queue.remove(new_source_job)
+                        break
+                else:
+                    fastr.log.debug('No queued source jobs that are valid to run')
+                    new_source_job = None
 
+                if new_source_job is not None:
                     fastr.log.debug('Selected {} to run'.format(new_source_job.id))
                     self.queued_source_jobs.append(new_source_job.id)
                     if self.SUPPORTS_HOLD_RELEASE:
