@@ -151,7 +151,7 @@ class XNATStorage(IOPlugin):
 
     def __init__(self):
         # initialize the instance and register the scheme
-        super(XNATStorage, self).__init__()
+        super().__init__()
         self._xnat = (None, None)
 
     def cleanup(self):
